==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PolitykaBezpieczenstwa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PolitykaBezpieczenstwa extends GenericDPSObject {
    /**
     * POLITYKA_BEZPIECZENSTWA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer dlHistoriiHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer minDlHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer maxDlHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer probNLogowan;

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer probCzasBlokady;

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer lDniObowiazywaniaHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer lDniZmianaHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean zastosuj;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLITYKA_BEZPIECZENSTWA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getDlHistoriiHasla() {
        return dlHistoriiHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     *
     * @param dlHistoriiHasla
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDlHistoriiHasla(Integer dlHistoriiHasla) {
        this.dlHistoriiHasla = dlHistoriiHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMinDlHasla() {
        return minDlHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     *
     * @param minDlHasla
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMinDlHasla(Integer minDlHasla) {
        this.minDlHasla = minDlHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMaxDlHasla() {
        return maxDlHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     *
     * @param maxDlHasla
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMaxDlHasla(Integer maxDlHasla) {
        this.maxDlHasla = maxDlHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getProbNLogowan() {
        return probNLogowan;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     *
     * @param probNLogowan
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setProbNLogowan(Integer probNLogowan) {
        this.probNLogowan = probNLogowan;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getProbCzasBlokady() {
        return probCzasBlokady;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     *
     * @param probCzasBlokady
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setProbCzasBlokady(Integer probCzasBlokady) {
        this.probCzasBlokady = probCzasBlokady;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getlDniObowiazywaniaHasla() {
        return lDniObowiazywaniaHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     *
     * @param lDniObowiazywaniaHasla
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setlDniObowiazywaniaHasla(Integer lDniObowiazywaniaHasla) {
        this.lDniObowiazywaniaHasla = lDniObowiazywaniaHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getlDniZmianaHasla() {
        return lDniZmianaHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     *
     * @param lDniZmianaHasla
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setlDniZmianaHasla(Integer lDniZmianaHasla) {
        this.lDniZmianaHasla = lDniZmianaHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getZastosuj() {
        return zastosuj;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     *
     * @param zastosuj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZastosuj(Boolean zastosuj) {
        this.zastosuj = zastosuj;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PolitykaBezpieczenstwa other = (PolitykaBezpieczenstwa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDlHistoriiHasla() == null ? other.getDlHistoriiHasla() == null : this.getDlHistoriiHasla().equals(other.getDlHistoriiHasla()))
            && (this.getMinDlHasla() == null ? other.getMinDlHasla() == null : this.getMinDlHasla().equals(other.getMinDlHasla()))
            && (this.getMaxDlHasla() == null ? other.getMaxDlHasla() == null : this.getMaxDlHasla().equals(other.getMaxDlHasla()))
            && (this.getProbNLogowan() == null ? other.getProbNLogowan() == null : this.getProbNLogowan().equals(other.getProbNLogowan()))
            && (this.getProbCzasBlokady() == null ? other.getProbCzasBlokady() == null : this.getProbCzasBlokady().equals(other.getProbCzasBlokady()))
            && (this.getlDniObowiazywaniaHasla() == null ? other.getlDniObowiazywaniaHasla() == null : this.getlDniObowiazywaniaHasla().equals(other.getlDniObowiazywaniaHasla()))
            && (this.getlDniZmianaHasla() == null ? other.getlDniZmianaHasla() == null : this.getlDniZmianaHasla().equals(other.getlDniZmianaHasla()))
            && (this.getZastosuj() == null ? other.getZastosuj() == null : this.getZastosuj().equals(other.getZastosuj()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDlHistoriiHasla() == null) ? 0 : getDlHistoriiHasla().hashCode());
        result = prime * result + ((getMinDlHasla() == null) ? 0 : getMinDlHasla().hashCode());
        result = prime * result + ((getMaxDlHasla() == null) ? 0 : getMaxDlHasla().hashCode());
        result = prime * result + ((getProbNLogowan() == null) ? 0 : getProbNLogowan().hashCode());
        result = prime * result + ((getProbCzasBlokady() == null) ? 0 : getProbCzasBlokady().hashCode());
        result = prime * result + ((getlDniObowiazywaniaHasla() == null) ? 0 : getlDniObowiazywaniaHasla().hashCode());
        result = prime * result + ((getlDniZmianaHasla() == null) ? 0 : getlDniZmianaHasla().hashCode());
        result = prime * result + ((getZastosuj() == null) ? 0 : getZastosuj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dlHistoriiHasla=").append(dlHistoriiHasla);
        sb.append(", minDlHasla=").append(minDlHasla);
        sb.append(", maxDlHasla=").append(maxDlHasla);
        sb.append(", probNLogowan=").append(probNLogowan);
        sb.append(", probCzasBlokady=").append(probCzasBlokady);
        sb.append(", lDniObowiazywaniaHasla=").append(lDniObowiazywaniaHasla);
        sb.append(", lDniZmianaHasla=").append(lDniZmianaHasla);
        sb.append(", zastosuj=").append(zastosuj);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PolitykaBezpieczenstwa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PolitykaBezpieczenstwa extends GenericDPSObject {
    /**
     * POLITYKA_BEZPIECZENSTWA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer dlHistoriiHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer minDlHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer maxDlHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer probNLogowan;

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer probCzasBlokady;

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer lDniObowiazywaniaHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer lDniZmianaHasla;

    /**
     * POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean zastosuj;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLITYKA_BEZPIECZENSTWA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getDlHistoriiHasla() {
        return dlHistoriiHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.DL_HISTORII_HASLA
     *
     * @param dlHistoriiHasla
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDlHistoriiHasla(Integer dlHistoriiHasla) {
        this.dlHistoriiHasla = dlHistoriiHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMinDlHasla() {
        return minDlHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.MIN_DL_HASLA
     *
     * @param minDlHasla
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMinDlHasla(Integer minDlHasla) {
        this.minDlHasla = minDlHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMaxDlHasla() {
        return maxDlHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.MAX_DL_HASLA
     *
     * @param maxDlHasla
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMaxDlHasla(Integer maxDlHasla) {
        this.maxDlHasla = maxDlHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getProbNLogowan() {
        return probNLogowan;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_N_LOGOWAN
     *
     * @param probNLogowan
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setProbNLogowan(Integer probNLogowan) {
        this.probNLogowan = probNLogowan;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getProbCzasBlokady() {
        return probCzasBlokady;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.PROB_CZAS_BLOKADY
     *
     * @param probCzasBlokady
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setProbCzasBlokady(Integer probCzasBlokady) {
        this.probCzasBlokady = probCzasBlokady;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getlDniObowiazywaniaHasla() {
        return lDniObowiazywaniaHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_OBOWIAZYWANIA_HASLA
     *
     * @param lDniObowiazywaniaHasla
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setlDniObowiazywaniaHasla(Integer lDniObowiazywaniaHasla) {
        this.lDniObowiazywaniaHasla = lDniObowiazywaniaHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getlDniZmianaHasla() {
        return lDniZmianaHasla;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.L_DNI_ZMIANA_HASLA
     *
     * @param lDniZmianaHasla
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setlDniZmianaHasla(Integer lDniZmianaHasla) {
        this.lDniZmianaHasla = lDniZmianaHasla;
    }

    /**
     * @return POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getZastosuj() {
        return zastosuj;
    }

    /**
     * POLITYKA_BEZPIECZENSTWA.ZASTOSUJ
     *
     * @param zastosuj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZastosuj(Boolean zastosuj) {
        this.zastosuj = zastosuj;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PolitykaBezpieczenstwa other = (PolitykaBezpieczenstwa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDlHistoriiHasla() == null ? other.getDlHistoriiHasla() == null : this.getDlHistoriiHasla().equals(other.getDlHistoriiHasla()))
            && (this.getMinDlHasla() == null ? other.getMinDlHasla() == null : this.getMinDlHasla().equals(other.getMinDlHasla()))
            && (this.getMaxDlHasla() == null ? other.getMaxDlHasla() == null : this.getMaxDlHasla().equals(other.getMaxDlHasla()))
            && (this.getProbNLogowan() == null ? other.getProbNLogowan() == null : this.getProbNLogowan().equals(other.getProbNLogowan()))
            && (this.getProbCzasBlokady() == null ? other.getProbCzasBlokady() == null : this.getProbCzasBlokady().equals(other.getProbCzasBlokady()))
            && (this.getlDniObowiazywaniaHasla() == null ? other.getlDniObowiazywaniaHasla() == null : this.getlDniObowiazywaniaHasla().equals(other.getlDniObowiazywaniaHasla()))
            && (this.getlDniZmianaHasla() == null ? other.getlDniZmianaHasla() == null : this.getlDniZmianaHasla().equals(other.getlDniZmianaHasla()))
            && (this.getZastosuj() == null ? other.getZastosuj() == null : this.getZastosuj().equals(other.getZastosuj()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDlHistoriiHasla() == null) ? 0 : getDlHistoriiHasla().hashCode());
        result = prime * result + ((getMinDlHasla() == null) ? 0 : getMinDlHasla().hashCode());
        result = prime * result + ((getMaxDlHasla() == null) ? 0 : getMaxDlHasla().hashCode());
        result = prime * result + ((getProbNLogowan() == null) ? 0 : getProbNLogowan().hashCode());
        result = prime * result + ((getProbCzasBlokady() == null) ? 0 : getProbCzasBlokady().hashCode());
        result = prime * result + ((getlDniObowiazywaniaHasla() == null) ? 0 : getlDniObowiazywaniaHasla().hashCode());
        result = prime * result + ((getlDniZmianaHasla() == null) ? 0 : getlDniZmianaHasla().hashCode());
        result = prime * result + ((getZastosuj() == null) ? 0 : getZastosuj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dlHistoriiHasla=").append(dlHistoriiHasla);
        sb.append(", minDlHasla=").append(minDlHasla);
        sb.append(", maxDlHasla=").append(maxDlHasla);
        sb.append(", probNLogowan=").append(probNLogowan);
        sb.append(", probCzasBlokady=").append(probCzasBlokady);
        sb.append(", lDniObowiazywaniaHasla=").append(lDniObowiazywaniaHasla);
        sb.append(", lDniZmianaHasla=").append(lDniZmianaHasla);
        sb.append(", zastosuj=").append(zastosuj);
        sb.append("]");
        return sb.toString();
    }
}
